@@ -1,6 +1,6 @@
 import pipes
 
-from fabric.api import settings, task, local, hide
+from fabric.api import settings, task, local, hide, lcd
 from fabric.contrib.console import confirm
 
 
@@ -32,11 +32,19 @@ def compass():
 def livereload():
     local('bundle exec guard')
 
+
 @task
 def coffee():
     local('coffee -c -w -j irco/explorer/static/scripts/master.js '
           'irco/explorer/assets/coffeescripts')
 
+
+@task
+def docs():
+    with lcd('docs'):
+        local('make html')
+
+
 @task
 def authors():
     """
@@ -53,7 +61,7 @@ def release():
 
     if not is_working_tree_clean():
         print 'Your working tree is not clean. Refusing to create a release.'
-        #return
+        return
 
     print 'Rebuilding the AUTHORS file to check for modifications...'
     authors()
@@ -64,7 +72,7 @@ def release():
             'rebuilt.'
         )
         print 'Please commit the changes before continuing.'
-        #return
+        return
 
     local('compass compile -c irco/explorer/assets/sass/config.rb')
     local('coffee -c -j irco/explorer/static/scripts/master.js '
@@ -88,8 +96,8 @@ def release():
         print 'Aborting.'
         return
 
-    #local('git tag -a {} -m {}'.format(pipes.quote(version),
-    #                                   pipes.quote(tag_message)))
+    local('git tag -a {} -m {}'.format(pipes.quote(version),
+                                       pipes.quote(tag_message)))
 
     # Push
     local('git push --tags origin master')
