@@ -1,7 +1,9 @@
 import argparse
-import tablib
 import sys
 
+from sqlalchemy import create_engine
+from sqlalchemy.orm import sessionmaker
+
 from irco import graphs
 
 
@@ -11,21 +13,21 @@ def write(fh, graph, format=None):
 
 
 def main():
-    format_choices = []
     graph_choices = graphs.get_graphs()
     argparser = argparse.ArgumentParser('irco-graph')
-    argparser.add_argument('-f', '--format', choices=format_choices)
+    argparser.add_argument('-v', '--verbose', action='store_true')
     argparser.add_argument('graph_type', choices=graph_choices)
-    argparser.add_argument('source')
+    argparser.add_argument('database')
     argparser.add_argument('output', default='-', nargs='?')
 
     args = argparser.parse_args()
 
-    with open(args.source, 'r') as fh:
-        dataset = tablib.import_set(fh)
+    engine = create_engine(args.database, echo=args.verbose)
 
     graph_factory = graphs.get_graph(args.graph_type)
-    graph = graph_factory.create(dataset)
+
+    Session = sessionmaker(bind=engine)
+    graph = graph_factory.create(Session())
 
     if args.output == '-':
         write(sys.stdout, graph)
